# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from onshape_client.api_client import ApiClient


class MetadataApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_veop_standard_content_metadata(self, did, vid, eid, otype, oid, pid, **kwargs):  # noqa: E501
        """get_veop_standard_content_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_veop_standard_content_metadata(did, vid, eid, otype, oid, pid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str vid: (required)
        :param str eid: (required)
        :param str otype: (required)
        :param str oid: (required)
        :param str pid: (required)
        :param str configuration:
        :param str link_document_id:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_veop_standard_content_metadata_with_http_info(did, vid, eid, otype, oid, pid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_veop_standard_content_metadata_with_http_info(did, vid, eid, otype, oid, pid, **kwargs)  # noqa: E501
            return data

    def get_veop_standard_content_metadata_with_http_info(self, did, vid, eid, otype, oid, pid, **kwargs):  # noqa: E501
        """get_veop_standard_content_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_veop_standard_content_metadata_with_http_info(did, vid, eid, otype, oid, pid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str vid: (required)
        :param str eid: (required)
        :param str otype: (required)
        :param str oid: (required)
        :param str pid: (required)
        :param str configuration:
        :param str link_document_id:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'vid', 'eid', 'otype', 'oid', 'pid', 'configuration', 'link_document_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_veop_standard_content_metadata" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_veop_standard_content_metadata`")  # noqa: E501
        # verify the required parameter 'vid' is set
        if ('vid' not in local_var_params or
                local_var_params['vid'] is None):
            raise ValueError("Missing the required parameter `vid` when calling `get_veop_standard_content_metadata`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `get_veop_standard_content_metadata`")  # noqa: E501
        # verify the required parameter 'otype' is set
        if ('otype' not in local_var_params or
                local_var_params['otype'] is None):
            raise ValueError("Missing the required parameter `otype` when calling `get_veop_standard_content_metadata`")  # noqa: E501
        # verify the required parameter 'oid' is set
        if ('oid' not in local_var_params or
                local_var_params['oid'] is None):
            raise ValueError("Missing the required parameter `oid` when calling `get_veop_standard_content_metadata`")  # noqa: E501
        # verify the required parameter 'pid' is set
        if ('pid' not in local_var_params or
                local_var_params['pid'] is None):
            raise ValueError("Missing the required parameter `pid` when calling `get_veop_standard_content_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'vid' in local_var_params:
            path_params['vid'] = local_var_params['vid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501
        if 'otype' in local_var_params:
            path_params['otype'] = local_var_params['otype']  # noqa: E501
        if 'oid' in local_var_params:
            path_params['oid'] = local_var_params['oid']  # noqa: E501
        if 'pid' in local_var_params:
            path_params['pid'] = local_var_params['pid']  # noqa: E501

        query_params = []
        if 'configuration' in local_var_params:
            query_params.append(('configuration', local_var_params['configuration']))  # noqa: E501
        if 'link_document_id' in local_var_params:
            query_params.append(('linkDocumentId', local_var_params['link_document_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/metadata/standardcontent/d/{did}/v/{vid}/e/{eid}/{otype}/{oid}/p/{pid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_wmve_ps_metadata(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """get_wmve_ps_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_wmve_ps_metadata(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param str configuration:
        :param str link_document_id:
        :param bool infer_metadata_owner:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_wmve_ps_metadata_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_wmve_ps_metadata_with_http_info(did, wvm, wvmid, eid, **kwargs)  # noqa: E501
            return data

    def get_wmve_ps_metadata_with_http_info(self, did, wvm, wvmid, eid, **kwargs):  # noqa: E501
        """get_wmve_ps_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_wmve_ps_metadata_with_http_info(did, wvm, wvmid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param str configuration:
        :param str link_document_id:
        :param bool infer_metadata_owner:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wvm', 'wvmid', 'eid', 'configuration', 'link_document_id', 'infer_metadata_owner']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_wmve_ps_metadata" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_wmve_ps_metadata`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `get_wmve_ps_metadata`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `get_wmve_ps_metadata`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `get_wmve_ps_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []
        if 'configuration' in local_var_params:
            query_params.append(('configuration', local_var_params['configuration']))  # noqa: E501
        if 'link_document_id' in local_var_params:
            query_params.append(('linkDocumentId', local_var_params['link_document_id']))  # noqa: E501
        if 'infer_metadata_owner' in local_var_params:
            query_params.append(('inferMetadataOwner', local_var_params['infer_metadata_owner']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/metadata/d/{did}/{wvm}/{wvmid}/e/{eid}/p', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_wmvep_metadata(self, did, wvm, wvmid, eid, pid, **kwargs):  # noqa: E501
        """get_wmvep_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_wmvep_metadata(did, wvm, wvmid, eid, pid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param str pid: (required)
        :param str configuration:
        :param str link_document_id:
        :param bool infer_metadata_owner:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_wmvep_metadata_with_http_info(did, wvm, wvmid, eid, pid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_wmvep_metadata_with_http_info(did, wvm, wvmid, eid, pid, **kwargs)  # noqa: E501
            return data

    def get_wmvep_metadata_with_http_info(self, did, wvm, wvmid, eid, pid, **kwargs):  # noqa: E501
        """get_wmvep_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_wmvep_metadata_with_http_info(did, wvm, wvmid, eid, pid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str eid: (required)
        :param str pid: (required)
        :param str configuration:
        :param str link_document_id:
        :param bool infer_metadata_owner:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wvm', 'wvmid', 'eid', 'pid', 'configuration', 'link_document_id', 'infer_metadata_owner']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_wmvep_metadata" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_wmvep_metadata`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `get_wmvep_metadata`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `get_wmvep_metadata`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `get_wmvep_metadata`")  # noqa: E501
        # verify the required parameter 'pid' is set
        if ('pid' not in local_var_params or
                local_var_params['pid'] is None):
            raise ValueError("Missing the required parameter `pid` when calling `get_wmvep_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501
        if 'pid' in local_var_params:
            path_params['pid'] = local_var_params['pid']  # noqa: E501

        query_params = []
        if 'configuration' in local_var_params:
            query_params.append(('configuration', local_var_params['configuration']))  # noqa: E501
        if 'link_document_id' in local_var_params:
            query_params.append(('linkDocumentId', local_var_params['link_document_id']))  # noqa: E501
        if 'infer_metadata_owner' in local_var_params:
            query_params.append(('inferMetadataOwner', local_var_params['infer_metadata_owner']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/metadata/d/{did}/{wvm}/{wvmid}/e/{eid}/p/{pid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_wv_es_metadata(self, did, wv, wvid, **kwargs):  # noqa: E501
        """get_wv_es_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_wv_es_metadata(did, wv, wvid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wv: (required)
        :param str wvid: (required)
        :param str link_document_id:
        :param bool infer_metadata_owner:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_wv_es_metadata_with_http_info(did, wv, wvid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_wv_es_metadata_with_http_info(did, wv, wvid, **kwargs)  # noqa: E501
            return data

    def get_wv_es_metadata_with_http_info(self, did, wv, wvid, **kwargs):  # noqa: E501
        """get_wv_es_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_wv_es_metadata_with_http_info(did, wv, wvid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wv: (required)
        :param str wvid: (required)
        :param str link_document_id:
        :param bool infer_metadata_owner:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wv', 'wvid', 'link_document_id', 'infer_metadata_owner']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_wv_es_metadata" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_wv_es_metadata`")  # noqa: E501
        # verify the required parameter 'wv' is set
        if ('wv' not in local_var_params or
                local_var_params['wv'] is None):
            raise ValueError("Missing the required parameter `wv` when calling `get_wv_es_metadata`")  # noqa: E501
        # verify the required parameter 'wvid' is set
        if ('wvid' not in local_var_params or
                local_var_params['wvid'] is None):
            raise ValueError("Missing the required parameter `wvid` when calling `get_wv_es_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wv' in local_var_params:
            path_params['wv'] = local_var_params['wv']  # noqa: E501
        if 'wvid' in local_var_params:
            path_params['wvid'] = local_var_params['wvid']  # noqa: E501

        query_params = []
        if 'link_document_id' in local_var_params:
            query_params.append(('linkDocumentId', local_var_params['link_document_id']))  # noqa: E501
        if 'infer_metadata_owner' in local_var_params:
            query_params.append(('inferMetadataOwner', local_var_params['infer_metadata_owner']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/metadata/d/{did}/{wv}/{wvid}/e', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_wv_metadata(self, did, wv, wvid, **kwargs):  # noqa: E501
        """get_wv_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_wv_metadata(did, wv, wvid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wv: (required)
        :param str wvid: (required)
        :param str link_document_id:
        :param bool infer_metadata_owner:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_wv_metadata_with_http_info(did, wv, wvid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_wv_metadata_with_http_info(did, wv, wvid, **kwargs)  # noqa: E501
            return data

    def get_wv_metadata_with_http_info(self, did, wv, wvid, **kwargs):  # noqa: E501
        """get_wv_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_wv_metadata_with_http_info(did, wv, wvid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wv: (required)
        :param str wvid: (required)
        :param str link_document_id:
        :param bool infer_metadata_owner:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wv', 'wvid', 'link_document_id', 'infer_metadata_owner']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_wv_metadata" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_wv_metadata`")  # noqa: E501
        # verify the required parameter 'wv' is set
        if ('wv' not in local_var_params or
                local_var_params['wv'] is None):
            raise ValueError("Missing the required parameter `wv` when calling `get_wv_metadata`")  # noqa: E501
        # verify the required parameter 'wvid' is set
        if ('wvid' not in local_var_params or
                local_var_params['wvid'] is None):
            raise ValueError("Missing the required parameter `wvid` when calling `get_wv_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wv' in local_var_params:
            path_params['wv'] = local_var_params['wv']  # noqa: E501
        if 'wvid' in local_var_params:
            path_params['wvid'] = local_var_params['wvid']  # noqa: E501

        query_params = []
        if 'link_document_id' in local_var_params:
            query_params.append(('linkDocumentId', local_var_params['link_document_id']))  # noqa: E501
        if 'infer_metadata_owner' in local_var_params:
            query_params.append(('inferMetadataOwner', local_var_params['infer_metadata_owner']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/metadata/d/{did}/{wv}/{wvid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_wve_metadata(self, did, wv, wvid, eid, **kwargs):  # noqa: E501
        """get_wve_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_wve_metadata(did, wv, wvid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wv: (required)
        :param str wvid: (required)
        :param str eid: (required)
        :param str configuration:
        :param str link_document_id:
        :param bool infer_metadata_owner:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_wve_metadata_with_http_info(did, wv, wvid, eid, **kwargs)  # noqa: E501
        else:
            (data) = self.get_wve_metadata_with_http_info(did, wv, wvid, eid, **kwargs)  # noqa: E501
            return data

    def get_wve_metadata_with_http_info(self, did, wv, wvid, eid, **kwargs):  # noqa: E501
        """get_wve_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_wve_metadata_with_http_info(did, wv, wvid, eid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wv: (required)
        :param str wvid: (required)
        :param str eid: (required)
        :param str configuration:
        :param str link_document_id:
        :param bool infer_metadata_owner:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wv', 'wvid', 'eid', 'configuration', 'link_document_id', 'infer_metadata_owner']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_wve_metadata" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `get_wve_metadata`")  # noqa: E501
        # verify the required parameter 'wv' is set
        if ('wv' not in local_var_params or
                local_var_params['wv'] is None):
            raise ValueError("Missing the required parameter `wv` when calling `get_wve_metadata`")  # noqa: E501
        # verify the required parameter 'wvid' is set
        if ('wvid' not in local_var_params or
                local_var_params['wvid'] is None):
            raise ValueError("Missing the required parameter `wvid` when calling `get_wve_metadata`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `get_wve_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wv' in local_var_params:
            path_params['wv'] = local_var_params['wv']  # noqa: E501
        if 'wvid' in local_var_params:
            path_params['wvid'] = local_var_params['wvid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []
        if 'configuration' in local_var_params:
            query_params.append(('configuration', local_var_params['configuration']))  # noqa: E501
        if 'link_document_id' in local_var_params:
            query_params.append(('linkDocumentId', local_var_params['link_document_id']))  # noqa: E501
        if 'infer_metadata_owner' in local_var_params:
            query_params.append(('inferMetadataOwner', local_var_params['infer_metadata_owner']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/metadata/d/{did}/{wv}/{wvid}/e/{eid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_veop_standard_content_part_metadata(self, did, vid, eid, otype, oid, pid, body, **kwargs):  # noqa: E501
        """update_veop_standard_content_part_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_veop_standard_content_part_metadata(did, vid, eid, otype, oid, pid, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str vid: (required)
        :param str eid: (required)
        :param str otype: (required)
        :param str oid: (required)
        :param str pid: (required)
        :param str body: (required)
        :param str link_document_id:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_veop_standard_content_part_metadata_with_http_info(did, vid, eid, otype, oid, pid, body, **kwargs)  # noqa: E501
        else:
            (data) = self.update_veop_standard_content_part_metadata_with_http_info(did, vid, eid, otype, oid, pid, body, **kwargs)  # noqa: E501
            return data

    def update_veop_standard_content_part_metadata_with_http_info(self, did, vid, eid, otype, oid, pid, body, **kwargs):  # noqa: E501
        """update_veop_standard_content_part_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_veop_standard_content_part_metadata_with_http_info(did, vid, eid, otype, oid, pid, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str vid: (required)
        :param str eid: (required)
        :param str otype: (required)
        :param str oid: (required)
        :param str pid: (required)
        :param str body: (required)
        :param str link_document_id:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'vid', 'eid', 'otype', 'oid', 'pid', 'body', 'link_document_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_veop_standard_content_part_metadata" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `update_veop_standard_content_part_metadata`")  # noqa: E501
        # verify the required parameter 'vid' is set
        if ('vid' not in local_var_params or
                local_var_params['vid'] is None):
            raise ValueError("Missing the required parameter `vid` when calling `update_veop_standard_content_part_metadata`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `update_veop_standard_content_part_metadata`")  # noqa: E501
        # verify the required parameter 'otype' is set
        if ('otype' not in local_var_params or
                local_var_params['otype'] is None):
            raise ValueError("Missing the required parameter `otype` when calling `update_veop_standard_content_part_metadata`")  # noqa: E501
        # verify the required parameter 'oid' is set
        if ('oid' not in local_var_params or
                local_var_params['oid'] is None):
            raise ValueError("Missing the required parameter `oid` when calling `update_veop_standard_content_part_metadata`")  # noqa: E501
        # verify the required parameter 'pid' is set
        if ('pid' not in local_var_params or
                local_var_params['pid'] is None):
            raise ValueError("Missing the required parameter `pid` when calling `update_veop_standard_content_part_metadata`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in local_var_params or
                local_var_params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_veop_standard_content_part_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'vid' in local_var_params:
            path_params['vid'] = local_var_params['vid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501
        if 'otype' in local_var_params:
            path_params['otype'] = local_var_params['otype']  # noqa: E501
        if 'oid' in local_var_params:
            path_params['oid'] = local_var_params['oid']  # noqa: E501
        if 'pid' in local_var_params:
            path_params['pid'] = local_var_params['pid']  # noqa: E501

        query_params = []
        if 'link_document_id' in local_var_params:
            query_params.append(('linkDocumentId', local_var_params['link_document_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/metadata/standardcontent/d/{did}/v/{vid}/e/{eid}/{otype}/{oid}/p/{pid}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_wv_metadata(self, did, wv, wvid, body, **kwargs):  # noqa: E501
        """update_wv_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_wv_metadata(did, wv, wvid, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wv: (required)
        :param str wvid: (required)
        :param str body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_wv_metadata_with_http_info(did, wv, wvid, body, **kwargs)  # noqa: E501
        else:
            (data) = self.update_wv_metadata_with_http_info(did, wv, wvid, body, **kwargs)  # noqa: E501
            return data

    def update_wv_metadata_with_http_info(self, did, wv, wvid, body, **kwargs):  # noqa: E501
        """update_wv_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_wv_metadata_with_http_info(did, wv, wvid, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wv: (required)
        :param str wvid: (required)
        :param str body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wv', 'wvid', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_wv_metadata" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `update_wv_metadata`")  # noqa: E501
        # verify the required parameter 'wv' is set
        if ('wv' not in local_var_params or
                local_var_params['wv'] is None):
            raise ValueError("Missing the required parameter `wv` when calling `update_wv_metadata`")  # noqa: E501
        # verify the required parameter 'wvid' is set
        if ('wvid' not in local_var_params or
                local_var_params['wvid'] is None):
            raise ValueError("Missing the required parameter `wvid` when calling `update_wv_metadata`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in local_var_params or
                local_var_params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_wv_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wv' in local_var_params:
            path_params['wv'] = local_var_params['wv']  # noqa: E501
        if 'wvid' in local_var_params:
            path_params['wvid'] = local_var_params['wvid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/metadata/d/{did}/{wv}/{wvid}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_wve_metadata(self, did, wv, wvid, eid, body, **kwargs):  # noqa: E501
        """update_wve_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_wve_metadata(did, wv, wvid, eid, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wv: (required)
        :param str wvid: (required)
        :param str eid: (required)
        :param str body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_wve_metadata_with_http_info(did, wv, wvid, eid, body, **kwargs)  # noqa: E501
        else:
            (data) = self.update_wve_metadata_with_http_info(did, wv, wvid, eid, body, **kwargs)  # noqa: E501
            return data

    def update_wve_metadata_with_http_info(self, did, wv, wvid, eid, body, **kwargs):  # noqa: E501
        """update_wve_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_wve_metadata_with_http_info(did, wv, wvid, eid, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wv: (required)
        :param str wvid: (required)
        :param str eid: (required)
        :param str body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wv', 'wvid', 'eid', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_wve_metadata" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `update_wve_metadata`")  # noqa: E501
        # verify the required parameter 'wv' is set
        if ('wv' not in local_var_params or
                local_var_params['wv'] is None):
            raise ValueError("Missing the required parameter `wv` when calling `update_wve_metadata`")  # noqa: E501
        # verify the required parameter 'wvid' is set
        if ('wvid' not in local_var_params or
                local_var_params['wvid'] is None):
            raise ValueError("Missing the required parameter `wvid` when calling `update_wve_metadata`")  # noqa: E501
        # verify the required parameter 'eid' is set
        if ('eid' not in local_var_params or
                local_var_params['eid'] is None):
            raise ValueError("Missing the required parameter `eid` when calling `update_wve_metadata`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in local_var_params or
                local_var_params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_wve_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wv' in local_var_params:
            path_params['wv'] = local_var_params['wv']  # noqa: E501
        if 'wvid' in local_var_params:
            path_params['wvid'] = local_var_params['wvid']  # noqa: E501
        if 'eid' in local_var_params:
            path_params['eid'] = local_var_params['eid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/metadata/d/{did}/{wv}/{wvid}/e/{eid}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_wvep_metadata(self, did, wvm, wvmid, sub_resource, body, **kwargs):  # noqa: E501
        """update_wvep_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_wvep_metadata(did, wvm, wvmid, sub_resource, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str sub_resource: (required)
        :param str body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_wvep_metadata_with_http_info(did, wvm, wvmid, sub_resource, body, **kwargs)  # noqa: E501
        else:
            (data) = self.update_wvep_metadata_with_http_info(did, wvm, wvmid, sub_resource, body, **kwargs)  # noqa: E501
            return data

    def update_wvep_metadata_with_http_info(self, did, wvm, wvmid, sub_resource, body, **kwargs):  # noqa: E501
        """update_wvep_metadata  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_wvep_metadata_with_http_info(did, wvm, wvmid, sub_resource, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str did: (required)
        :param str wvm: (required)
        :param str wvmid: (required)
        :param str sub_resource: (required)
        :param str body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['did', 'wvm', 'wvmid', 'sub_resource', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_wvep_metadata" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'did' is set
        if ('did' not in local_var_params or
                local_var_params['did'] is None):
            raise ValueError("Missing the required parameter `did` when calling `update_wvep_metadata`")  # noqa: E501
        # verify the required parameter 'wvm' is set
        if ('wvm' not in local_var_params or
                local_var_params['wvm'] is None):
            raise ValueError("Missing the required parameter `wvm` when calling `update_wvep_metadata`")  # noqa: E501
        # verify the required parameter 'wvmid' is set
        if ('wvmid' not in local_var_params or
                local_var_params['wvmid'] is None):
            raise ValueError("Missing the required parameter `wvmid` when calling `update_wvep_metadata`")  # noqa: E501
        # verify the required parameter 'sub_resource' is set
        if ('sub_resource' not in local_var_params or
                local_var_params['sub_resource'] is None):
            raise ValueError("Missing the required parameter `sub_resource` when calling `update_wvep_metadata`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in local_var_params or
                local_var_params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_wvep_metadata`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'did' in local_var_params:
            path_params['did'] = local_var_params['did']  # noqa: E501
        if 'wvm' in local_var_params:
            path_params['wvm'] = local_var_params['wvm']  # noqa: E501
        if 'wvmid' in local_var_params:
            path_params['wvmid'] = local_var_params['wvmid']  # noqa: E501
        if 'sub_resource' in local_var_params:
            path_params['subResource'] = local_var_params['sub_resource']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/metadata/d/{did}/{wvm}/{wvmid}/e/{eid}/p/{pid}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTUserAgentVersion(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'patch_version': 'int',
        'major_version': 'int',
        'minor_version': 'int'
    }

    attribute_map = {
        'patch_version': 'patchVersion',
        'major_version': 'majorVersion',
        'minor_version': 'minorVersion'
    }

    def __init__(self, patch_version=None, major_version=None, minor_version=None):  # noqa: E501
        """BTUserAgentVersion - a model defined in OpenAPI"""  # noqa: E501

        self._patch_version = None
        self._major_version = None
        self._minor_version = None
        self.discriminator = None

        if patch_version is not None:
            self.patch_version = patch_version
        if major_version is not None:
            self.major_version = major_version
        if minor_version is not None:
            self.minor_version = minor_version

    @property
    def patch_version(self):
        """Gets the patch_version of this BTUserAgentVersion.  # noqa: E501


        :return: The patch_version of this BTUserAgentVersion.  # noqa: E501
        :rtype: int
        """
        return self._patch_version

    @patch_version.setter
    def patch_version(self, patch_version):
        """Sets the patch_version of this BTUserAgentVersion.


        :param patch_version: The patch_version of this BTUserAgentVersion.  # noqa: E501
        :type: int
        """

        self._patch_version = patch_version

    @property
    def major_version(self):
        """Gets the major_version of this BTUserAgentVersion.  # noqa: E501


        :return: The major_version of this BTUserAgentVersion.  # noqa: E501
        :rtype: int
        """
        return self._major_version

    @major_version.setter
    def major_version(self, major_version):
        """Sets the major_version of this BTUserAgentVersion.


        :param major_version: The major_version of this BTUserAgentVersion.  # noqa: E501
        :type: int
        """

        self._major_version = major_version

    @property
    def minor_version(self):
        """Gets the minor_version of this BTUserAgentVersion.  # noqa: E501


        :return: The minor_version of this BTUserAgentVersion.  # noqa: E501
        :rtype: int
        """
        return self._minor_version

    @minor_version.setter
    def minor_version(self, minor_version):
        """Sets the minor_version of this BTUserAgentVersion.


        :param minor_version: The minor_version of this BTUserAgentVersion.  # noqa: E501
        :type: int
        """

        self._minor_version = minor_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTUserAgentVersion):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTCompanyPoliciesParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'require_totp': 'bool',
        'use_light_ui': 'bool',
        'only_admins_can_mark_objects_as_not_revision_managed': 'bool',
        'require_approved_drawing_templates': 'bool',
        'approved_drawing_templates_document_id': 'str',
        'add_company_owned_libraries_in_user_account': 'bool',
        'release_workflow_id': 'str',
        'obsoletion_workflow_id': 'str',
        'revision_scheme_id': 'str',
        'require_revision_for_released_objects': 'bool',
        'require_part_number_for_released_objects': 'bool',
        'only_admins_can_edit_properties_of_released_objects': 'bool',
        'only_admins_can_delete_documents_containing_released_objects': 'bool',
        'only_admins_can_approve_releases': 'bool',
        'require_parts_and_subassemblies_release_with_assembly': 'bool',
        'require_parts_and_subassemblies_release_with_drawing': 'bool',
        'require_base_part_release_with_derived_part': 'bool',
        'require_image_release_with_drawing': 'bool',
        'action_show_drawings_watermark': 'bool',
        'prevent_duplicate_document_name_regex': 'str',
        'error_on_feature_list_errors_during_release': 'bool',
        'error_on_rollback_bar_not_at_end_during_release': 'bool',
        'error_on_assembly_tree_errors_during_release': 'bool',
        'error_on_pending_context_edits_during_release': 'bool',
        'error_on_pending_drawing_update_during_release': 'bool',
        'error_on_pending_dangling_drawing_objects_during_release': 'bool',
        'approver_required_during_release': 'bool',
        'note_required_during_release': 'bool',
        'require_all_approvers': 'bool',
        'automatically_obsolete_previous_released_revisions': 'bool',
        'part_numbering_scheme_id': 'str',
        'require_peer_review': 'bool',
        'drawing_can_duplicate_part_number': 'bool'
    }

    attribute_map = {
        'require_totp': 'requireTotp',
        'use_light_ui': 'useLightUi',
        'only_admins_can_mark_objects_as_not_revision_managed': 'onlyAdminsCanMarkObjectsAsNotRevisionManaged',
        'require_approved_drawing_templates': 'requireApprovedDrawingTemplates',
        'approved_drawing_templates_document_id': 'approvedDrawingTemplatesDocumentId',
        'add_company_owned_libraries_in_user_account': 'addCompanyOwnedLibrariesInUserAccount',
        'release_workflow_id': 'releaseWorkflowId',
        'obsoletion_workflow_id': 'obsoletionWorkflowId',
        'revision_scheme_id': 'revisionSchemeId',
        'require_revision_for_released_objects': 'requireRevisionForReleasedObjects',
        'require_part_number_for_released_objects': 'requirePartNumberForReleasedObjects',
        'only_admins_can_edit_properties_of_released_objects': 'onlyAdminsCanEditPropertiesOfReleasedObjects',
        'only_admins_can_delete_documents_containing_released_objects': 'onlyAdminsCanDeleteDocumentsContainingReleasedObjects',
        'only_admins_can_approve_releases': 'onlyAdminsCanApproveReleases',
        'require_parts_and_subassemblies_release_with_assembly': 'requirePartsAndSubassembliesReleaseWithAssembly',
        'require_parts_and_subassemblies_release_with_drawing': 'requirePartsAndSubassembliesReleaseWithDrawing',
        'require_base_part_release_with_derived_part': 'requireBasePartReleaseWithDerivedPart',
        'require_image_release_with_drawing': 'requireImageReleaseWithDrawing',
        'action_show_drawings_watermark': 'actionShowDrawingsWatermark',
        'prevent_duplicate_document_name_regex': 'preventDuplicateDocumentNameRegex',
        'error_on_feature_list_errors_during_release': 'errorOnFeatureListErrorsDuringRelease',
        'error_on_rollback_bar_not_at_end_during_release': 'errorOnRollbackBarNotAtEndDuringRelease',
        'error_on_assembly_tree_errors_during_release': 'errorOnAssemblyTreeErrorsDuringRelease',
        'error_on_pending_context_edits_during_release': 'errorOnPendingContextEditsDuringRelease',
        'error_on_pending_drawing_update_during_release': 'errorOnPendingDrawingUpdateDuringRelease',
        'error_on_pending_dangling_drawing_objects_during_release': 'errorOnPendingDanglingDrawingObjectsDuringRelease',
        'approver_required_during_release': 'approverRequiredDuringRelease',
        'note_required_during_release': 'noteRequiredDuringRelease',
        'require_all_approvers': 'requireAllApprovers',
        'automatically_obsolete_previous_released_revisions': 'automaticallyObsoletePreviousReleasedRevisions',
        'part_numbering_scheme_id': 'partNumberingSchemeId',
        'require_peer_review': 'requirePeerReview',
        'drawing_can_duplicate_part_number': 'drawingCanDuplicatePartNumber'
    }

    def __init__(self, require_totp=None, use_light_ui=None, only_admins_can_mark_objects_as_not_revision_managed=None, require_approved_drawing_templates=None, approved_drawing_templates_document_id=None, add_company_owned_libraries_in_user_account=None, release_workflow_id=None, obsoletion_workflow_id=None, revision_scheme_id=None, require_revision_for_released_objects=None, require_part_number_for_released_objects=None, only_admins_can_edit_properties_of_released_objects=None, only_admins_can_delete_documents_containing_released_objects=None, only_admins_can_approve_releases=None, require_parts_and_subassemblies_release_with_assembly=None, require_parts_and_subassemblies_release_with_drawing=None, require_base_part_release_with_derived_part=None, require_image_release_with_drawing=None, action_show_drawings_watermark=None, prevent_duplicate_document_name_regex=None, error_on_feature_list_errors_during_release=None, error_on_rollback_bar_not_at_end_during_release=None, error_on_assembly_tree_errors_during_release=None, error_on_pending_context_edits_during_release=None, error_on_pending_drawing_update_during_release=None, error_on_pending_dangling_drawing_objects_during_release=None, approver_required_during_release=None, note_required_during_release=None, require_all_approvers=None, automatically_obsolete_previous_released_revisions=None, part_numbering_scheme_id=None, require_peer_review=None, drawing_can_duplicate_part_number=None):  # noqa: E501
        """BTCompanyPoliciesParams - a model defined in OpenAPI"""  # noqa: E501

        self._require_totp = None
        self._use_light_ui = None
        self._only_admins_can_mark_objects_as_not_revision_managed = None
        self._require_approved_drawing_templates = None
        self._approved_drawing_templates_document_id = None
        self._add_company_owned_libraries_in_user_account = None
        self._release_workflow_id = None
        self._obsoletion_workflow_id = None
        self._revision_scheme_id = None
        self._require_revision_for_released_objects = None
        self._require_part_number_for_released_objects = None
        self._only_admins_can_edit_properties_of_released_objects = None
        self._only_admins_can_delete_documents_containing_released_objects = None
        self._only_admins_can_approve_releases = None
        self._require_parts_and_subassemblies_release_with_assembly = None
        self._require_parts_and_subassemblies_release_with_drawing = None
        self._require_base_part_release_with_derived_part = None
        self._require_image_release_with_drawing = None
        self._action_show_drawings_watermark = None
        self._prevent_duplicate_document_name_regex = None
        self._error_on_feature_list_errors_during_release = None
        self._error_on_rollback_bar_not_at_end_during_release = None
        self._error_on_assembly_tree_errors_during_release = None
        self._error_on_pending_context_edits_during_release = None
        self._error_on_pending_drawing_update_during_release = None
        self._error_on_pending_dangling_drawing_objects_during_release = None
        self._approver_required_during_release = None
        self._note_required_during_release = None
        self._require_all_approvers = None
        self._automatically_obsolete_previous_released_revisions = None
        self._part_numbering_scheme_id = None
        self._require_peer_review = None
        self._drawing_can_duplicate_part_number = None
        self.discriminator = None

        if require_totp is not None:
            self.require_totp = require_totp
        if use_light_ui is not None:
            self.use_light_ui = use_light_ui
        if only_admins_can_mark_objects_as_not_revision_managed is not None:
            self.only_admins_can_mark_objects_as_not_revision_managed = only_admins_can_mark_objects_as_not_revision_managed
        if require_approved_drawing_templates is not None:
            self.require_approved_drawing_templates = require_approved_drawing_templates
        if approved_drawing_templates_document_id is not None:
            self.approved_drawing_templates_document_id = approved_drawing_templates_document_id
        if add_company_owned_libraries_in_user_account is not None:
            self.add_company_owned_libraries_in_user_account = add_company_owned_libraries_in_user_account
        if release_workflow_id is not None:
            self.release_workflow_id = release_workflow_id
        if obsoletion_workflow_id is not None:
            self.obsoletion_workflow_id = obsoletion_workflow_id
        if revision_scheme_id is not None:
            self.revision_scheme_id = revision_scheme_id
        if require_revision_for_released_objects is not None:
            self.require_revision_for_released_objects = require_revision_for_released_objects
        if require_part_number_for_released_objects is not None:
            self.require_part_number_for_released_objects = require_part_number_for_released_objects
        if only_admins_can_edit_properties_of_released_objects is not None:
            self.only_admins_can_edit_properties_of_released_objects = only_admins_can_edit_properties_of_released_objects
        if only_admins_can_delete_documents_containing_released_objects is not None:
            self.only_admins_can_delete_documents_containing_released_objects = only_admins_can_delete_documents_containing_released_objects
        if only_admins_can_approve_releases is not None:
            self.only_admins_can_approve_releases = only_admins_can_approve_releases
        if require_parts_and_subassemblies_release_with_assembly is not None:
            self.require_parts_and_subassemblies_release_with_assembly = require_parts_and_subassemblies_release_with_assembly
        if require_parts_and_subassemblies_release_with_drawing is not None:
            self.require_parts_and_subassemblies_release_with_drawing = require_parts_and_subassemblies_release_with_drawing
        if require_base_part_release_with_derived_part is not None:
            self.require_base_part_release_with_derived_part = require_base_part_release_with_derived_part
        if require_image_release_with_drawing is not None:
            self.require_image_release_with_drawing = require_image_release_with_drawing
        if action_show_drawings_watermark is not None:
            self.action_show_drawings_watermark = action_show_drawings_watermark
        if prevent_duplicate_document_name_regex is not None:
            self.prevent_duplicate_document_name_regex = prevent_duplicate_document_name_regex
        if error_on_feature_list_errors_during_release is not None:
            self.error_on_feature_list_errors_during_release = error_on_feature_list_errors_during_release
        if error_on_rollback_bar_not_at_end_during_release is not None:
            self.error_on_rollback_bar_not_at_end_during_release = error_on_rollback_bar_not_at_end_during_release
        if error_on_assembly_tree_errors_during_release is not None:
            self.error_on_assembly_tree_errors_during_release = error_on_assembly_tree_errors_during_release
        if error_on_pending_context_edits_during_release is not None:
            self.error_on_pending_context_edits_during_release = error_on_pending_context_edits_during_release
        if error_on_pending_drawing_update_during_release is not None:
            self.error_on_pending_drawing_update_during_release = error_on_pending_drawing_update_during_release
        if error_on_pending_dangling_drawing_objects_during_release is not None:
            self.error_on_pending_dangling_drawing_objects_during_release = error_on_pending_dangling_drawing_objects_during_release
        if approver_required_during_release is not None:
            self.approver_required_during_release = approver_required_during_release
        if note_required_during_release is not None:
            self.note_required_during_release = note_required_during_release
        if require_all_approvers is not None:
            self.require_all_approvers = require_all_approvers
        if automatically_obsolete_previous_released_revisions is not None:
            self.automatically_obsolete_previous_released_revisions = automatically_obsolete_previous_released_revisions
        if part_numbering_scheme_id is not None:
            self.part_numbering_scheme_id = part_numbering_scheme_id
        if require_peer_review is not None:
            self.require_peer_review = require_peer_review
        if drawing_can_duplicate_part_number is not None:
            self.drawing_can_duplicate_part_number = drawing_can_duplicate_part_number

    @property
    def require_totp(self):
        """Gets the require_totp of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The require_totp of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._require_totp

    @require_totp.setter
    def require_totp(self, require_totp):
        """Sets the require_totp of this BTCompanyPoliciesParams.


        :param require_totp: The require_totp of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._require_totp = require_totp

    @property
    def use_light_ui(self):
        """Gets the use_light_ui of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The use_light_ui of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._use_light_ui

    @use_light_ui.setter
    def use_light_ui(self, use_light_ui):
        """Sets the use_light_ui of this BTCompanyPoliciesParams.


        :param use_light_ui: The use_light_ui of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._use_light_ui = use_light_ui

    @property
    def only_admins_can_mark_objects_as_not_revision_managed(self):
        """Gets the only_admins_can_mark_objects_as_not_revision_managed of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The only_admins_can_mark_objects_as_not_revision_managed of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._only_admins_can_mark_objects_as_not_revision_managed

    @only_admins_can_mark_objects_as_not_revision_managed.setter
    def only_admins_can_mark_objects_as_not_revision_managed(self, only_admins_can_mark_objects_as_not_revision_managed):
        """Sets the only_admins_can_mark_objects_as_not_revision_managed of this BTCompanyPoliciesParams.


        :param only_admins_can_mark_objects_as_not_revision_managed: The only_admins_can_mark_objects_as_not_revision_managed of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._only_admins_can_mark_objects_as_not_revision_managed = only_admins_can_mark_objects_as_not_revision_managed

    @property
    def require_approved_drawing_templates(self):
        """Gets the require_approved_drawing_templates of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The require_approved_drawing_templates of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._require_approved_drawing_templates

    @require_approved_drawing_templates.setter
    def require_approved_drawing_templates(self, require_approved_drawing_templates):
        """Sets the require_approved_drawing_templates of this BTCompanyPoliciesParams.


        :param require_approved_drawing_templates: The require_approved_drawing_templates of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._require_approved_drawing_templates = require_approved_drawing_templates

    @property
    def approved_drawing_templates_document_id(self):
        """Gets the approved_drawing_templates_document_id of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The approved_drawing_templates_document_id of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: str
        """
        return self._approved_drawing_templates_document_id

    @approved_drawing_templates_document_id.setter
    def approved_drawing_templates_document_id(self, approved_drawing_templates_document_id):
        """Sets the approved_drawing_templates_document_id of this BTCompanyPoliciesParams.


        :param approved_drawing_templates_document_id: The approved_drawing_templates_document_id of this BTCompanyPoliciesParams.  # noqa: E501
        :type: str
        """

        self._approved_drawing_templates_document_id = approved_drawing_templates_document_id

    @property
    def add_company_owned_libraries_in_user_account(self):
        """Gets the add_company_owned_libraries_in_user_account of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The add_company_owned_libraries_in_user_account of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._add_company_owned_libraries_in_user_account

    @add_company_owned_libraries_in_user_account.setter
    def add_company_owned_libraries_in_user_account(self, add_company_owned_libraries_in_user_account):
        """Sets the add_company_owned_libraries_in_user_account of this BTCompanyPoliciesParams.


        :param add_company_owned_libraries_in_user_account: The add_company_owned_libraries_in_user_account of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._add_company_owned_libraries_in_user_account = add_company_owned_libraries_in_user_account

    @property
    def release_workflow_id(self):
        """Gets the release_workflow_id of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The release_workflow_id of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: str
        """
        return self._release_workflow_id

    @release_workflow_id.setter
    def release_workflow_id(self, release_workflow_id):
        """Sets the release_workflow_id of this BTCompanyPoliciesParams.


        :param release_workflow_id: The release_workflow_id of this BTCompanyPoliciesParams.  # noqa: E501
        :type: str
        """

        self._release_workflow_id = release_workflow_id

    @property
    def obsoletion_workflow_id(self):
        """Gets the obsoletion_workflow_id of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The obsoletion_workflow_id of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: str
        """
        return self._obsoletion_workflow_id

    @obsoletion_workflow_id.setter
    def obsoletion_workflow_id(self, obsoletion_workflow_id):
        """Sets the obsoletion_workflow_id of this BTCompanyPoliciesParams.


        :param obsoletion_workflow_id: The obsoletion_workflow_id of this BTCompanyPoliciesParams.  # noqa: E501
        :type: str
        """

        self._obsoletion_workflow_id = obsoletion_workflow_id

    @property
    def revision_scheme_id(self):
        """Gets the revision_scheme_id of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The revision_scheme_id of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: str
        """
        return self._revision_scheme_id

    @revision_scheme_id.setter
    def revision_scheme_id(self, revision_scheme_id):
        """Sets the revision_scheme_id of this BTCompanyPoliciesParams.


        :param revision_scheme_id: The revision_scheme_id of this BTCompanyPoliciesParams.  # noqa: E501
        :type: str
        """

        self._revision_scheme_id = revision_scheme_id

    @property
    def require_revision_for_released_objects(self):
        """Gets the require_revision_for_released_objects of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The require_revision_for_released_objects of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._require_revision_for_released_objects

    @require_revision_for_released_objects.setter
    def require_revision_for_released_objects(self, require_revision_for_released_objects):
        """Sets the require_revision_for_released_objects of this BTCompanyPoliciesParams.


        :param require_revision_for_released_objects: The require_revision_for_released_objects of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._require_revision_for_released_objects = require_revision_for_released_objects

    @property
    def require_part_number_for_released_objects(self):
        """Gets the require_part_number_for_released_objects of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The require_part_number_for_released_objects of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._require_part_number_for_released_objects

    @require_part_number_for_released_objects.setter
    def require_part_number_for_released_objects(self, require_part_number_for_released_objects):
        """Sets the require_part_number_for_released_objects of this BTCompanyPoliciesParams.


        :param require_part_number_for_released_objects: The require_part_number_for_released_objects of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._require_part_number_for_released_objects = require_part_number_for_released_objects

    @property
    def only_admins_can_edit_properties_of_released_objects(self):
        """Gets the only_admins_can_edit_properties_of_released_objects of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The only_admins_can_edit_properties_of_released_objects of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._only_admins_can_edit_properties_of_released_objects

    @only_admins_can_edit_properties_of_released_objects.setter
    def only_admins_can_edit_properties_of_released_objects(self, only_admins_can_edit_properties_of_released_objects):
        """Sets the only_admins_can_edit_properties_of_released_objects of this BTCompanyPoliciesParams.


        :param only_admins_can_edit_properties_of_released_objects: The only_admins_can_edit_properties_of_released_objects of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._only_admins_can_edit_properties_of_released_objects = only_admins_can_edit_properties_of_released_objects

    @property
    def only_admins_can_delete_documents_containing_released_objects(self):
        """Gets the only_admins_can_delete_documents_containing_released_objects of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The only_admins_can_delete_documents_containing_released_objects of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._only_admins_can_delete_documents_containing_released_objects

    @only_admins_can_delete_documents_containing_released_objects.setter
    def only_admins_can_delete_documents_containing_released_objects(self, only_admins_can_delete_documents_containing_released_objects):
        """Sets the only_admins_can_delete_documents_containing_released_objects of this BTCompanyPoliciesParams.


        :param only_admins_can_delete_documents_containing_released_objects: The only_admins_can_delete_documents_containing_released_objects of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._only_admins_can_delete_documents_containing_released_objects = only_admins_can_delete_documents_containing_released_objects

    @property
    def only_admins_can_approve_releases(self):
        """Gets the only_admins_can_approve_releases of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The only_admins_can_approve_releases of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._only_admins_can_approve_releases

    @only_admins_can_approve_releases.setter
    def only_admins_can_approve_releases(self, only_admins_can_approve_releases):
        """Sets the only_admins_can_approve_releases of this BTCompanyPoliciesParams.


        :param only_admins_can_approve_releases: The only_admins_can_approve_releases of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._only_admins_can_approve_releases = only_admins_can_approve_releases

    @property
    def require_parts_and_subassemblies_release_with_assembly(self):
        """Gets the require_parts_and_subassemblies_release_with_assembly of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The require_parts_and_subassemblies_release_with_assembly of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._require_parts_and_subassemblies_release_with_assembly

    @require_parts_and_subassemblies_release_with_assembly.setter
    def require_parts_and_subassemblies_release_with_assembly(self, require_parts_and_subassemblies_release_with_assembly):
        """Sets the require_parts_and_subassemblies_release_with_assembly of this BTCompanyPoliciesParams.


        :param require_parts_and_subassemblies_release_with_assembly: The require_parts_and_subassemblies_release_with_assembly of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._require_parts_and_subassemblies_release_with_assembly = require_parts_and_subassemblies_release_with_assembly

    @property
    def require_parts_and_subassemblies_release_with_drawing(self):
        """Gets the require_parts_and_subassemblies_release_with_drawing of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The require_parts_and_subassemblies_release_with_drawing of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._require_parts_and_subassemblies_release_with_drawing

    @require_parts_and_subassemblies_release_with_drawing.setter
    def require_parts_and_subassemblies_release_with_drawing(self, require_parts_and_subassemblies_release_with_drawing):
        """Sets the require_parts_and_subassemblies_release_with_drawing of this BTCompanyPoliciesParams.


        :param require_parts_and_subassemblies_release_with_drawing: The require_parts_and_subassemblies_release_with_drawing of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._require_parts_and_subassemblies_release_with_drawing = require_parts_and_subassemblies_release_with_drawing

    @property
    def require_base_part_release_with_derived_part(self):
        """Gets the require_base_part_release_with_derived_part of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The require_base_part_release_with_derived_part of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._require_base_part_release_with_derived_part

    @require_base_part_release_with_derived_part.setter
    def require_base_part_release_with_derived_part(self, require_base_part_release_with_derived_part):
        """Sets the require_base_part_release_with_derived_part of this BTCompanyPoliciesParams.


        :param require_base_part_release_with_derived_part: The require_base_part_release_with_derived_part of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._require_base_part_release_with_derived_part = require_base_part_release_with_derived_part

    @property
    def require_image_release_with_drawing(self):
        """Gets the require_image_release_with_drawing of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The require_image_release_with_drawing of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._require_image_release_with_drawing

    @require_image_release_with_drawing.setter
    def require_image_release_with_drawing(self, require_image_release_with_drawing):
        """Sets the require_image_release_with_drawing of this BTCompanyPoliciesParams.


        :param require_image_release_with_drawing: The require_image_release_with_drawing of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._require_image_release_with_drawing = require_image_release_with_drawing

    @property
    def action_show_drawings_watermark(self):
        """Gets the action_show_drawings_watermark of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The action_show_drawings_watermark of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._action_show_drawings_watermark

    @action_show_drawings_watermark.setter
    def action_show_drawings_watermark(self, action_show_drawings_watermark):
        """Sets the action_show_drawings_watermark of this BTCompanyPoliciesParams.


        :param action_show_drawings_watermark: The action_show_drawings_watermark of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._action_show_drawings_watermark = action_show_drawings_watermark

    @property
    def prevent_duplicate_document_name_regex(self):
        """Gets the prevent_duplicate_document_name_regex of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The prevent_duplicate_document_name_regex of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: str
        """
        return self._prevent_duplicate_document_name_regex

    @prevent_duplicate_document_name_regex.setter
    def prevent_duplicate_document_name_regex(self, prevent_duplicate_document_name_regex):
        """Sets the prevent_duplicate_document_name_regex of this BTCompanyPoliciesParams.


        :param prevent_duplicate_document_name_regex: The prevent_duplicate_document_name_regex of this BTCompanyPoliciesParams.  # noqa: E501
        :type: str
        """

        self._prevent_duplicate_document_name_regex = prevent_duplicate_document_name_regex

    @property
    def error_on_feature_list_errors_during_release(self):
        """Gets the error_on_feature_list_errors_during_release of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The error_on_feature_list_errors_during_release of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._error_on_feature_list_errors_during_release

    @error_on_feature_list_errors_during_release.setter
    def error_on_feature_list_errors_during_release(self, error_on_feature_list_errors_during_release):
        """Sets the error_on_feature_list_errors_during_release of this BTCompanyPoliciesParams.


        :param error_on_feature_list_errors_during_release: The error_on_feature_list_errors_during_release of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._error_on_feature_list_errors_during_release = error_on_feature_list_errors_during_release

    @property
    def error_on_rollback_bar_not_at_end_during_release(self):
        """Gets the error_on_rollback_bar_not_at_end_during_release of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The error_on_rollback_bar_not_at_end_during_release of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._error_on_rollback_bar_not_at_end_during_release

    @error_on_rollback_bar_not_at_end_during_release.setter
    def error_on_rollback_bar_not_at_end_during_release(self, error_on_rollback_bar_not_at_end_during_release):
        """Sets the error_on_rollback_bar_not_at_end_during_release of this BTCompanyPoliciesParams.


        :param error_on_rollback_bar_not_at_end_during_release: The error_on_rollback_bar_not_at_end_during_release of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._error_on_rollback_bar_not_at_end_during_release = error_on_rollback_bar_not_at_end_during_release

    @property
    def error_on_assembly_tree_errors_during_release(self):
        """Gets the error_on_assembly_tree_errors_during_release of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The error_on_assembly_tree_errors_during_release of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._error_on_assembly_tree_errors_during_release

    @error_on_assembly_tree_errors_during_release.setter
    def error_on_assembly_tree_errors_during_release(self, error_on_assembly_tree_errors_during_release):
        """Sets the error_on_assembly_tree_errors_during_release of this BTCompanyPoliciesParams.


        :param error_on_assembly_tree_errors_during_release: The error_on_assembly_tree_errors_during_release of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._error_on_assembly_tree_errors_during_release = error_on_assembly_tree_errors_during_release

    @property
    def error_on_pending_context_edits_during_release(self):
        """Gets the error_on_pending_context_edits_during_release of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The error_on_pending_context_edits_during_release of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._error_on_pending_context_edits_during_release

    @error_on_pending_context_edits_during_release.setter
    def error_on_pending_context_edits_during_release(self, error_on_pending_context_edits_during_release):
        """Sets the error_on_pending_context_edits_during_release of this BTCompanyPoliciesParams.


        :param error_on_pending_context_edits_during_release: The error_on_pending_context_edits_during_release of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._error_on_pending_context_edits_during_release = error_on_pending_context_edits_during_release

    @property
    def error_on_pending_drawing_update_during_release(self):
        """Gets the error_on_pending_drawing_update_during_release of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The error_on_pending_drawing_update_during_release of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._error_on_pending_drawing_update_during_release

    @error_on_pending_drawing_update_during_release.setter
    def error_on_pending_drawing_update_during_release(self, error_on_pending_drawing_update_during_release):
        """Sets the error_on_pending_drawing_update_during_release of this BTCompanyPoliciesParams.


        :param error_on_pending_drawing_update_during_release: The error_on_pending_drawing_update_during_release of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._error_on_pending_drawing_update_during_release = error_on_pending_drawing_update_during_release

    @property
    def error_on_pending_dangling_drawing_objects_during_release(self):
        """Gets the error_on_pending_dangling_drawing_objects_during_release of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The error_on_pending_dangling_drawing_objects_during_release of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._error_on_pending_dangling_drawing_objects_during_release

    @error_on_pending_dangling_drawing_objects_during_release.setter
    def error_on_pending_dangling_drawing_objects_during_release(self, error_on_pending_dangling_drawing_objects_during_release):
        """Sets the error_on_pending_dangling_drawing_objects_during_release of this BTCompanyPoliciesParams.


        :param error_on_pending_dangling_drawing_objects_during_release: The error_on_pending_dangling_drawing_objects_during_release of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._error_on_pending_dangling_drawing_objects_during_release = error_on_pending_dangling_drawing_objects_during_release

    @property
    def approver_required_during_release(self):
        """Gets the approver_required_during_release of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The approver_required_during_release of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._approver_required_during_release

    @approver_required_during_release.setter
    def approver_required_during_release(self, approver_required_during_release):
        """Sets the approver_required_during_release of this BTCompanyPoliciesParams.


        :param approver_required_during_release: The approver_required_during_release of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._approver_required_during_release = approver_required_during_release

    @property
    def note_required_during_release(self):
        """Gets the note_required_during_release of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The note_required_during_release of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._note_required_during_release

    @note_required_during_release.setter
    def note_required_during_release(self, note_required_during_release):
        """Sets the note_required_during_release of this BTCompanyPoliciesParams.


        :param note_required_during_release: The note_required_during_release of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._note_required_during_release = note_required_during_release

    @property
    def require_all_approvers(self):
        """Gets the require_all_approvers of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The require_all_approvers of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._require_all_approvers

    @require_all_approvers.setter
    def require_all_approvers(self, require_all_approvers):
        """Sets the require_all_approvers of this BTCompanyPoliciesParams.


        :param require_all_approvers: The require_all_approvers of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._require_all_approvers = require_all_approvers

    @property
    def automatically_obsolete_previous_released_revisions(self):
        """Gets the automatically_obsolete_previous_released_revisions of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The automatically_obsolete_previous_released_revisions of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._automatically_obsolete_previous_released_revisions

    @automatically_obsolete_previous_released_revisions.setter
    def automatically_obsolete_previous_released_revisions(self, automatically_obsolete_previous_released_revisions):
        """Sets the automatically_obsolete_previous_released_revisions of this BTCompanyPoliciesParams.


        :param automatically_obsolete_previous_released_revisions: The automatically_obsolete_previous_released_revisions of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._automatically_obsolete_previous_released_revisions = automatically_obsolete_previous_released_revisions

    @property
    def part_numbering_scheme_id(self):
        """Gets the part_numbering_scheme_id of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The part_numbering_scheme_id of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: str
        """
        return self._part_numbering_scheme_id

    @part_numbering_scheme_id.setter
    def part_numbering_scheme_id(self, part_numbering_scheme_id):
        """Sets the part_numbering_scheme_id of this BTCompanyPoliciesParams.


        :param part_numbering_scheme_id: The part_numbering_scheme_id of this BTCompanyPoliciesParams.  # noqa: E501
        :type: str
        """

        self._part_numbering_scheme_id = part_numbering_scheme_id

    @property
    def require_peer_review(self):
        """Gets the require_peer_review of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The require_peer_review of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._require_peer_review

    @require_peer_review.setter
    def require_peer_review(self, require_peer_review):
        """Sets the require_peer_review of this BTCompanyPoliciesParams.


        :param require_peer_review: The require_peer_review of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._require_peer_review = require_peer_review

    @property
    def drawing_can_duplicate_part_number(self):
        """Gets the drawing_can_duplicate_part_number of this BTCompanyPoliciesParams.  # noqa: E501


        :return: The drawing_can_duplicate_part_number of this BTCompanyPoliciesParams.  # noqa: E501
        :rtype: bool
        """
        return self._drawing_can_duplicate_part_number

    @drawing_can_duplicate_part_number.setter
    def drawing_can_duplicate_part_number(self, drawing_can_duplicate_part_number):
        """Sets the drawing_can_duplicate_part_number of this BTCompanyPoliciesParams.


        :param drawing_can_duplicate_part_number: The drawing_can_duplicate_part_number of this BTCompanyPoliciesParams.  # noqa: E501
        :type: bool
        """

        self._drawing_can_duplicate_part_number = drawing_can_duplicate_part_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTCompanyPoliciesParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class PathItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'summary': 'str',
        'description': 'str',
        'get': 'Operation',
        'put': 'Operation',
        'post': 'Operation',
        'delete': 'Operation',
        'options': 'Operation',
        'head': 'Operation',
        'patch': 'Operation',
        'trace': 'Operation',
        'servers': 'list[Server]',
        'parameters': 'list[Parameter]',
        'getref': 'str',
        'extensions': 'dict(str, object)'
    }

    attribute_map = {
        'summary': 'summary',
        'description': 'description',
        'get': 'get',
        'put': 'put',
        'post': 'post',
        'delete': 'delete',
        'options': 'options',
        'head': 'head',
        'patch': 'patch',
        'trace': 'trace',
        'servers': 'servers',
        'parameters': 'parameters',
        'getref': 'get$ref',
        'extensions': 'extensions'
    }

    def __init__(self, summary=None, description=None, get=None, put=None, post=None, delete=None, options=None, head=None, patch=None, trace=None, servers=None, parameters=None, getref=None, extensions=None):  # noqa: E501
        """PathItem - a model defined in OpenAPI"""  # noqa: E501

        self._summary = None
        self._description = None
        self._get = None
        self._put = None
        self._post = None
        self._delete = None
        self._options = None
        self._head = None
        self._patch = None
        self._trace = None
        self._servers = None
        self._parameters = None
        self._getref = None
        self._extensions = None
        self.discriminator = None

        if summary is not None:
            self.summary = summary
        if description is not None:
            self.description = description
        if get is not None:
            self.get = get
        if put is not None:
            self.put = put
        if post is not None:
            self.post = post
        if delete is not None:
            self.delete = delete
        if options is not None:
            self.options = options
        if head is not None:
            self.head = head
        if patch is not None:
            self.patch = patch
        if trace is not None:
            self.trace = trace
        if servers is not None:
            self.servers = servers
        if parameters is not None:
            self.parameters = parameters
        if getref is not None:
            self.getref = getref
        if extensions is not None:
            self.extensions = extensions

    @property
    def summary(self):
        """Gets the summary of this PathItem.  # noqa: E501


        :return: The summary of this PathItem.  # noqa: E501
        :rtype: str
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """Sets the summary of this PathItem.


        :param summary: The summary of this PathItem.  # noqa: E501
        :type: str
        """

        self._summary = summary

    @property
    def description(self):
        """Gets the description of this PathItem.  # noqa: E501


        :return: The description of this PathItem.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PathItem.


        :param description: The description of this PathItem.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def get(self):
        """Gets the get of this PathItem.  # noqa: E501


        :return: The get of this PathItem.  # noqa: E501
        :rtype: Operation
        """
        return self._get

    @get.setter
    def get(self, get):
        """Sets the get of this PathItem.


        :param get: The get of this PathItem.  # noqa: E501
        :type: Operation
        """

        self._get = get

    @property
    def put(self):
        """Gets the put of this PathItem.  # noqa: E501


        :return: The put of this PathItem.  # noqa: E501
        :rtype: Operation
        """
        return self._put

    @put.setter
    def put(self, put):
        """Sets the put of this PathItem.


        :param put: The put of this PathItem.  # noqa: E501
        :type: Operation
        """

        self._put = put

    @property
    def post(self):
        """Gets the post of this PathItem.  # noqa: E501


        :return: The post of this PathItem.  # noqa: E501
        :rtype: Operation
        """
        return self._post

    @post.setter
    def post(self, post):
        """Sets the post of this PathItem.


        :param post: The post of this PathItem.  # noqa: E501
        :type: Operation
        """

        self._post = post

    @property
    def delete(self):
        """Gets the delete of this PathItem.  # noqa: E501


        :return: The delete of this PathItem.  # noqa: E501
        :rtype: Operation
        """
        return self._delete

    @delete.setter
    def delete(self, delete):
        """Sets the delete of this PathItem.


        :param delete: The delete of this PathItem.  # noqa: E501
        :type: Operation
        """

        self._delete = delete

    @property
    def options(self):
        """Gets the options of this PathItem.  # noqa: E501


        :return: The options of this PathItem.  # noqa: E501
        :rtype: Operation
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this PathItem.


        :param options: The options of this PathItem.  # noqa: E501
        :type: Operation
        """

        self._options = options

    @property
    def head(self):
        """Gets the head of this PathItem.  # noqa: E501


        :return: The head of this PathItem.  # noqa: E501
        :rtype: Operation
        """
        return self._head

    @head.setter
    def head(self, head):
        """Sets the head of this PathItem.


        :param head: The head of this PathItem.  # noqa: E501
        :type: Operation
        """

        self._head = head

    @property
    def patch(self):
        """Gets the patch of this PathItem.  # noqa: E501


        :return: The patch of this PathItem.  # noqa: E501
        :rtype: Operation
        """
        return self._patch

    @patch.setter
    def patch(self, patch):
        """Sets the patch of this PathItem.


        :param patch: The patch of this PathItem.  # noqa: E501
        :type: Operation
        """

        self._patch = patch

    @property
    def trace(self):
        """Gets the trace of this PathItem.  # noqa: E501


        :return: The trace of this PathItem.  # noqa: E501
        :rtype: Operation
        """
        return self._trace

    @trace.setter
    def trace(self, trace):
        """Sets the trace of this PathItem.


        :param trace: The trace of this PathItem.  # noqa: E501
        :type: Operation
        """

        self._trace = trace

    @property
    def servers(self):
        """Gets the servers of this PathItem.  # noqa: E501


        :return: The servers of this PathItem.  # noqa: E501
        :rtype: list[Server]
        """
        return self._servers

    @servers.setter
    def servers(self, servers):
        """Sets the servers of this PathItem.


        :param servers: The servers of this PathItem.  # noqa: E501
        :type: list[Server]
        """

        self._servers = servers

    @property
    def parameters(self):
        """Gets the parameters of this PathItem.  # noqa: E501


        :return: The parameters of this PathItem.  # noqa: E501
        :rtype: list[Parameter]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this PathItem.


        :param parameters: The parameters of this PathItem.  # noqa: E501
        :type: list[Parameter]
        """

        self._parameters = parameters

    @property
    def getref(self):
        """Gets the getref of this PathItem.  # noqa: E501


        :return: The getref of this PathItem.  # noqa: E501
        :rtype: str
        """
        return self._getref

    @getref.setter
    def getref(self, getref):
        """Sets the getref of this PathItem.


        :param getref: The getref of this PathItem.  # noqa: E501
        :type: str
        """

        self._getref = getref

    @property
    def extensions(self):
        """Gets the extensions of this PathItem.  # noqa: E501


        :return: The extensions of this PathItem.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._extensions

    @extensions.setter
    def extensions(self, extensions):
        """Sets the extensions of this PathItem.


        :param extensions: The extensions of this PathItem.  # noqa: E501
        :type: dict(str, object)
        """

        self._extensions = extensions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PathItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Encoding(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'content_type': 'str',
        'headers': 'dict(str, Header)',
        'style': 'str',
        'explode': 'bool',
        'allow_reserved': 'bool',
        'extensions': 'dict(str, object)'
    }

    attribute_map = {
        'content_type': 'contentType',
        'headers': 'headers',
        'style': 'style',
        'explode': 'explode',
        'allow_reserved': 'allowReserved',
        'extensions': 'extensions'
    }

    def __init__(self, content_type=None, headers=None, style=None, explode=None, allow_reserved=None, extensions=None):  # noqa: E501
        """Encoding - a model defined in OpenAPI"""  # noqa: E501

        self._content_type = None
        self._headers = None
        self._style = None
        self._explode = None
        self._allow_reserved = None
        self._extensions = None
        self.discriminator = None

        if content_type is not None:
            self.content_type = content_type
        if headers is not None:
            self.headers = headers
        if style is not None:
            self.style = style
        if explode is not None:
            self.explode = explode
        if allow_reserved is not None:
            self.allow_reserved = allow_reserved
        if extensions is not None:
            self.extensions = extensions

    @property
    def content_type(self):
        """Gets the content_type of this Encoding.  # noqa: E501


        :return: The content_type of this Encoding.  # noqa: E501
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """Sets the content_type of this Encoding.


        :param content_type: The content_type of this Encoding.  # noqa: E501
        :type: str
        """

        self._content_type = content_type

    @property
    def headers(self):
        """Gets the headers of this Encoding.  # noqa: E501


        :return: The headers of this Encoding.  # noqa: E501
        :rtype: dict(str, Header)
        """
        return self._headers

    @headers.setter
    def headers(self, headers):
        """Sets the headers of this Encoding.


        :param headers: The headers of this Encoding.  # noqa: E501
        :type: dict(str, Header)
        """

        self._headers = headers

    @property
    def style(self):
        """Gets the style of this Encoding.  # noqa: E501


        :return: The style of this Encoding.  # noqa: E501
        :rtype: str
        """
        return self._style

    @style.setter
    def style(self, style):
        """Sets the style of this Encoding.


        :param style: The style of this Encoding.  # noqa: E501
        :type: str
        """
        allowed_values = ["form", "spaceDelimited", "pipeDelimited", "deepObject"]  # noqa: E501
        if style not in allowed_values:
            raise ValueError(
                "Invalid value for `style` ({0}), must be one of {1}"  # noqa: E501
                .format(style, allowed_values)
            )

        self._style = style

    @property
    def explode(self):
        """Gets the explode of this Encoding.  # noqa: E501


        :return: The explode of this Encoding.  # noqa: E501
        :rtype: bool
        """
        return self._explode

    @explode.setter
    def explode(self, explode):
        """Sets the explode of this Encoding.


        :param explode: The explode of this Encoding.  # noqa: E501
        :type: bool
        """

        self._explode = explode

    @property
    def allow_reserved(self):
        """Gets the allow_reserved of this Encoding.  # noqa: E501


        :return: The allow_reserved of this Encoding.  # noqa: E501
        :rtype: bool
        """
        return self._allow_reserved

    @allow_reserved.setter
    def allow_reserved(self, allow_reserved):
        """Sets the allow_reserved of this Encoding.


        :param allow_reserved: The allow_reserved of this Encoding.  # noqa: E501
        :type: bool
        """

        self._allow_reserved = allow_reserved

    @property
    def extensions(self):
        """Gets the extensions of this Encoding.  # noqa: E501


        :return: The extensions of this Encoding.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._extensions

    @extensions.setter
    def extensions(self, extensions):
        """Sets the extensions of this Encoding.


        :param extensions: The extensions of this Encoding.  # noqa: E501
        :type: dict(str, object)
        """

        self._extensions = extensions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Encoding):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTViewDataInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'view_matrix': 'list[float]',
        'is_perspective': 'bool',
        'angle': 'float',
        'camera_viewport': 'list[float]'
    }

    attribute_map = {
        'view_matrix': 'viewMatrix',
        'is_perspective': 'isPerspective',
        'angle': 'angle',
        'camera_viewport': 'cameraViewport'
    }

    def __init__(self, view_matrix=None, is_perspective=None, angle=None, camera_viewport=None):  # noqa: E501
        """BTViewDataInfo - a model defined in OpenAPI"""  # noqa: E501

        self._view_matrix = None
        self._is_perspective = None
        self._angle = None
        self._camera_viewport = None
        self.discriminator = None

        if view_matrix is not None:
            self.view_matrix = view_matrix
        if is_perspective is not None:
            self.is_perspective = is_perspective
        if angle is not None:
            self.angle = angle
        if camera_viewport is not None:
            self.camera_viewport = camera_viewport

    @property
    def view_matrix(self):
        """Gets the view_matrix of this BTViewDataInfo.  # noqa: E501


        :return: The view_matrix of this BTViewDataInfo.  # noqa: E501
        :rtype: list[float]
        """
        return self._view_matrix

    @view_matrix.setter
    def view_matrix(self, view_matrix):
        """Sets the view_matrix of this BTViewDataInfo.


        :param view_matrix: The view_matrix of this BTViewDataInfo.  # noqa: E501
        :type: list[float]
        """

        self._view_matrix = view_matrix

    @property
    def is_perspective(self):
        """Gets the is_perspective of this BTViewDataInfo.  # noqa: E501


        :return: The is_perspective of this BTViewDataInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_perspective

    @is_perspective.setter
    def is_perspective(self, is_perspective):
        """Sets the is_perspective of this BTViewDataInfo.


        :param is_perspective: The is_perspective of this BTViewDataInfo.  # noqa: E501
        :type: bool
        """

        self._is_perspective = is_perspective

    @property
    def angle(self):
        """Gets the angle of this BTViewDataInfo.  # noqa: E501


        :return: The angle of this BTViewDataInfo.  # noqa: E501
        :rtype: float
        """
        return self._angle

    @angle.setter
    def angle(self, angle):
        """Sets the angle of this BTViewDataInfo.


        :param angle: The angle of this BTViewDataInfo.  # noqa: E501
        :type: float
        """

        self._angle = angle

    @property
    def camera_viewport(self):
        """Gets the camera_viewport of this BTViewDataInfo.  # noqa: E501


        :return: The camera_viewport of this BTViewDataInfo.  # noqa: E501
        :rtype: list[float]
        """
        return self._camera_viewport

    @camera_viewport.setter
    def camera_viewport(self, camera_viewport):
        """Sets the camera_viewport of this BTViewDataInfo.


        :param camera_viewport: The camera_viewport of this BTViewDataInfo.  # noqa: E501
        :type: list[float]
        """

        self._camera_viewport = camera_viewport

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTViewDataInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Parameter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        '_in': 'str',
        'description': 'str',
        'required': 'bool',
        'deprecated': 'bool',
        'allow_empty_value': 'bool',
        'getref': 'str',
        'style': 'str',
        'explode': 'bool',
        'allow_reserved': 'bool',
        'schema': 'Schema',
        'examples': 'dict(str, Example)',
        'example': 'object',
        'content': 'BodyPartHeaders',
        'extensions': 'dict(str, object)'
    }

    attribute_map = {
        'name': 'name',
        '_in': 'in',
        'description': 'description',
        'required': 'required',
        'deprecated': 'deprecated',
        'allow_empty_value': 'allowEmptyValue',
        'getref': 'get$ref',
        'style': 'style',
        'explode': 'explode',
        'allow_reserved': 'allowReserved',
        'schema': 'schema',
        'examples': 'examples',
        'example': 'example',
        'content': 'content',
        'extensions': 'extensions'
    }

    def __init__(self, name=None, _in=None, description=None, required=None, deprecated=None, allow_empty_value=None, getref=None, style=None, explode=None, allow_reserved=None, schema=None, examples=None, example=None, content=None, extensions=None):  # noqa: E501
        """Parameter - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self.__in = None
        self._description = None
        self._required = None
        self._deprecated = None
        self._allow_empty_value = None
        self._getref = None
        self._style = None
        self._explode = None
        self._allow_reserved = None
        self._schema = None
        self._examples = None
        self._example = None
        self._content = None
        self._extensions = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if _in is not None:
            self._in = _in
        if description is not None:
            self.description = description
        if required is not None:
            self.required = required
        if deprecated is not None:
            self.deprecated = deprecated
        if allow_empty_value is not None:
            self.allow_empty_value = allow_empty_value
        if getref is not None:
            self.getref = getref
        if style is not None:
            self.style = style
        if explode is not None:
            self.explode = explode
        if allow_reserved is not None:
            self.allow_reserved = allow_reserved
        if schema is not None:
            self.schema = schema
        if examples is not None:
            self.examples = examples
        if example is not None:
            self.example = example
        if content is not None:
            self.content = content
        if extensions is not None:
            self.extensions = extensions

    @property
    def name(self):
        """Gets the name of this Parameter.  # noqa: E501


        :return: The name of this Parameter.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Parameter.


        :param name: The name of this Parameter.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def _in(self):
        """Gets the _in of this Parameter.  # noqa: E501


        :return: The _in of this Parameter.  # noqa: E501
        :rtype: str
        """
        return self.__in

    @_in.setter
    def _in(self, _in):
        """Sets the _in of this Parameter.


        :param _in: The _in of this Parameter.  # noqa: E501
        :type: str
        """

        self.__in = _in

    @property
    def description(self):
        """Gets the description of this Parameter.  # noqa: E501


        :return: The description of this Parameter.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Parameter.


        :param description: The description of this Parameter.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def required(self):
        """Gets the required of this Parameter.  # noqa: E501


        :return: The required of this Parameter.  # noqa: E501
        :rtype: bool
        """
        return self._required

    @required.setter
    def required(self, required):
        """Sets the required of this Parameter.


        :param required: The required of this Parameter.  # noqa: E501
        :type: bool
        """

        self._required = required

    @property
    def deprecated(self):
        """Gets the deprecated of this Parameter.  # noqa: E501


        :return: The deprecated of this Parameter.  # noqa: E501
        :rtype: bool
        """
        return self._deprecated

    @deprecated.setter
    def deprecated(self, deprecated):
        """Sets the deprecated of this Parameter.


        :param deprecated: The deprecated of this Parameter.  # noqa: E501
        :type: bool
        """

        self._deprecated = deprecated

    @property
    def allow_empty_value(self):
        """Gets the allow_empty_value of this Parameter.  # noqa: E501


        :return: The allow_empty_value of this Parameter.  # noqa: E501
        :rtype: bool
        """
        return self._allow_empty_value

    @allow_empty_value.setter
    def allow_empty_value(self, allow_empty_value):
        """Sets the allow_empty_value of this Parameter.


        :param allow_empty_value: The allow_empty_value of this Parameter.  # noqa: E501
        :type: bool
        """

        self._allow_empty_value = allow_empty_value

    @property
    def getref(self):
        """Gets the getref of this Parameter.  # noqa: E501


        :return: The getref of this Parameter.  # noqa: E501
        :rtype: str
        """
        return self._getref

    @getref.setter
    def getref(self, getref):
        """Sets the getref of this Parameter.


        :param getref: The getref of this Parameter.  # noqa: E501
        :type: str
        """

        self._getref = getref

    @property
    def style(self):
        """Gets the style of this Parameter.  # noqa: E501


        :return: The style of this Parameter.  # noqa: E501
        :rtype: str
        """
        return self._style

    @style.setter
    def style(self, style):
        """Sets the style of this Parameter.


        :param style: The style of this Parameter.  # noqa: E501
        :type: str
        """
        allowed_values = ["matrix", "label", "form", "simple", "spaceDelimited", "pipeDelimited", "deepObject"]  # noqa: E501
        if style not in allowed_values:
            raise ValueError(
                "Invalid value for `style` ({0}), must be one of {1}"  # noqa: E501
                .format(style, allowed_values)
            )

        self._style = style

    @property
    def explode(self):
        """Gets the explode of this Parameter.  # noqa: E501


        :return: The explode of this Parameter.  # noqa: E501
        :rtype: bool
        """
        return self._explode

    @explode.setter
    def explode(self, explode):
        """Sets the explode of this Parameter.


        :param explode: The explode of this Parameter.  # noqa: E501
        :type: bool
        """

        self._explode = explode

    @property
    def allow_reserved(self):
        """Gets the allow_reserved of this Parameter.  # noqa: E501


        :return: The allow_reserved of this Parameter.  # noqa: E501
        :rtype: bool
        """
        return self._allow_reserved

    @allow_reserved.setter
    def allow_reserved(self, allow_reserved):
        """Sets the allow_reserved of this Parameter.


        :param allow_reserved: The allow_reserved of this Parameter.  # noqa: E501
        :type: bool
        """

        self._allow_reserved = allow_reserved

    @property
    def schema(self):
        """Gets the schema of this Parameter.  # noqa: E501


        :return: The schema of this Parameter.  # noqa: E501
        :rtype: Schema
        """
        return self._schema

    @schema.setter
    def schema(self, schema):
        """Sets the schema of this Parameter.


        :param schema: The schema of this Parameter.  # noqa: E501
        :type: Schema
        """

        self._schema = schema

    @property
    def examples(self):
        """Gets the examples of this Parameter.  # noqa: E501


        :return: The examples of this Parameter.  # noqa: E501
        :rtype: dict(str, Example)
        """
        return self._examples

    @examples.setter
    def examples(self, examples):
        """Sets the examples of this Parameter.


        :param examples: The examples of this Parameter.  # noqa: E501
        :type: dict(str, Example)
        """

        self._examples = examples

    @property
    def example(self):
        """Gets the example of this Parameter.  # noqa: E501


        :return: The example of this Parameter.  # noqa: E501
        :rtype: object
        """
        return self._example

    @example.setter
    def example(self, example):
        """Sets the example of this Parameter.


        :param example: The example of this Parameter.  # noqa: E501
        :type: object
        """

        self._example = example

    @property
    def content(self):
        """Gets the content of this Parameter.  # noqa: E501


        :return: The content of this Parameter.  # noqa: E501
        :rtype: BodyPartHeaders
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this Parameter.


        :param content: The content of this Parameter.  # noqa: E501
        :type: BodyPartHeaders
        """

        self._content = content

    @property
    def extensions(self):
        """Gets the extensions of this Parameter.  # noqa: E501


        :return: The extensions of this Parameter.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._extensions

    @extensions.setter
    def extensions(self, extensions):
        """Sets the extensions of this Parameter.


        :param extensions: The extensions of this Parameter.  # noqa: E501
        :type: dict(str, object)
        """

        self._extensions = extensions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Parameter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class ConfigurationInfoEntry(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'parameter_display_value': 'str',
        'explicit': 'bool',
        'parameter_id': 'str',
        'parameter_value': 'str',
        'parameter_name': 'str'
    }

    attribute_map = {
        'parameter_display_value': 'parameterDisplayValue',
        'explicit': 'explicit',
        'parameter_id': 'parameterId',
        'parameter_value': 'parameterValue',
        'parameter_name': 'parameterName'
    }

    def __init__(self, parameter_display_value=None, explicit=None, parameter_id=None, parameter_value=None, parameter_name=None):  # noqa: E501
        """ConfigurationInfoEntry - a model defined in OpenAPI"""  # noqa: E501

        self._parameter_display_value = None
        self._explicit = None
        self._parameter_id = None
        self._parameter_value = None
        self._parameter_name = None
        self.discriminator = None

        if parameter_display_value is not None:
            self.parameter_display_value = parameter_display_value
        if explicit is not None:
            self.explicit = explicit
        if parameter_id is not None:
            self.parameter_id = parameter_id
        if parameter_value is not None:
            self.parameter_value = parameter_value
        if parameter_name is not None:
            self.parameter_name = parameter_name

    @property
    def parameter_display_value(self):
        """Gets the parameter_display_value of this ConfigurationInfoEntry.  # noqa: E501


        :return: The parameter_display_value of this ConfigurationInfoEntry.  # noqa: E501
        :rtype: str
        """
        return self._parameter_display_value

    @parameter_display_value.setter
    def parameter_display_value(self, parameter_display_value):
        """Sets the parameter_display_value of this ConfigurationInfoEntry.


        :param parameter_display_value: The parameter_display_value of this ConfigurationInfoEntry.  # noqa: E501
        :type: str
        """

        self._parameter_display_value = parameter_display_value

    @property
    def explicit(self):
        """Gets the explicit of this ConfigurationInfoEntry.  # noqa: E501


        :return: The explicit of this ConfigurationInfoEntry.  # noqa: E501
        :rtype: bool
        """
        return self._explicit

    @explicit.setter
    def explicit(self, explicit):
        """Sets the explicit of this ConfigurationInfoEntry.


        :param explicit: The explicit of this ConfigurationInfoEntry.  # noqa: E501
        :type: bool
        """

        self._explicit = explicit

    @property
    def parameter_id(self):
        """Gets the parameter_id of this ConfigurationInfoEntry.  # noqa: E501


        :return: The parameter_id of this ConfigurationInfoEntry.  # noqa: E501
        :rtype: str
        """
        return self._parameter_id

    @parameter_id.setter
    def parameter_id(self, parameter_id):
        """Sets the parameter_id of this ConfigurationInfoEntry.


        :param parameter_id: The parameter_id of this ConfigurationInfoEntry.  # noqa: E501
        :type: str
        """

        self._parameter_id = parameter_id

    @property
    def parameter_value(self):
        """Gets the parameter_value of this ConfigurationInfoEntry.  # noqa: E501


        :return: The parameter_value of this ConfigurationInfoEntry.  # noqa: E501
        :rtype: str
        """
        return self._parameter_value

    @parameter_value.setter
    def parameter_value(self, parameter_value):
        """Sets the parameter_value of this ConfigurationInfoEntry.


        :param parameter_value: The parameter_value of this ConfigurationInfoEntry.  # noqa: E501
        :type: str
        """

        self._parameter_value = parameter_value

    @property
    def parameter_name(self):
        """Gets the parameter_name of this ConfigurationInfoEntry.  # noqa: E501


        :return: The parameter_name of this ConfigurationInfoEntry.  # noqa: E501
        :rtype: str
        """
        return self._parameter_name

    @parameter_name.setter
    def parameter_name(self, parameter_name):
        """Sets the parameter_name of this ConfigurationInfoEntry.


        :param parameter_name: The parameter_name of this ConfigurationInfoEntry.  # noqa: E501
        :type: str
        """

        self._parameter_name = parameter_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConfigurationInfoEntry):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTMetadataPropertyValidatorInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'max': 'float',
        'min': 'float',
        'pattern': 'str',
        'min_length': 'int',
        'max_length': 'int',
        'min_date': 'datetime',
        'max_date': 'datetime',
        'min_count': 'int',
        'max_count': 'int'
    }

    attribute_map = {
        'max': 'max',
        'min': 'min',
        'pattern': 'pattern',
        'min_length': 'minLength',
        'max_length': 'maxLength',
        'min_date': 'minDate',
        'max_date': 'maxDate',
        'min_count': 'minCount',
        'max_count': 'maxCount'
    }

    def __init__(self, max=None, min=None, pattern=None, min_length=None, max_length=None, min_date=None, max_date=None, min_count=None, max_count=None):  # noqa: E501
        """BTMetadataPropertyValidatorInfo - a model defined in OpenAPI"""  # noqa: E501

        self._max = None
        self._min = None
        self._pattern = None
        self._min_length = None
        self._max_length = None
        self._min_date = None
        self._max_date = None
        self._min_count = None
        self._max_count = None
        self.discriminator = None

        if max is not None:
            self.max = max
        if min is not None:
            self.min = min
        if pattern is not None:
            self.pattern = pattern
        if min_length is not None:
            self.min_length = min_length
        if max_length is not None:
            self.max_length = max_length
        if min_date is not None:
            self.min_date = min_date
        if max_date is not None:
            self.max_date = max_date
        if min_count is not None:
            self.min_count = min_count
        if max_count is not None:
            self.max_count = max_count

    @property
    def max(self):
        """Gets the max of this BTMetadataPropertyValidatorInfo.  # noqa: E501


        :return: The max of this BTMetadataPropertyValidatorInfo.  # noqa: E501
        :rtype: float
        """
        return self._max

    @max.setter
    def max(self, max):
        """Sets the max of this BTMetadataPropertyValidatorInfo.


        :param max: The max of this BTMetadataPropertyValidatorInfo.  # noqa: E501
        :type: float
        """

        self._max = max

    @property
    def min(self):
        """Gets the min of this BTMetadataPropertyValidatorInfo.  # noqa: E501


        :return: The min of this BTMetadataPropertyValidatorInfo.  # noqa: E501
        :rtype: float
        """
        return self._min

    @min.setter
    def min(self, min):
        """Sets the min of this BTMetadataPropertyValidatorInfo.


        :param min: The min of this BTMetadataPropertyValidatorInfo.  # noqa: E501
        :type: float
        """

        self._min = min

    @property
    def pattern(self):
        """Gets the pattern of this BTMetadataPropertyValidatorInfo.  # noqa: E501


        :return: The pattern of this BTMetadataPropertyValidatorInfo.  # noqa: E501
        :rtype: str
        """
        return self._pattern

    @pattern.setter
    def pattern(self, pattern):
        """Sets the pattern of this BTMetadataPropertyValidatorInfo.


        :param pattern: The pattern of this BTMetadataPropertyValidatorInfo.  # noqa: E501
        :type: str
        """

        self._pattern = pattern

    @property
    def min_length(self):
        """Gets the min_length of this BTMetadataPropertyValidatorInfo.  # noqa: E501


        :return: The min_length of this BTMetadataPropertyValidatorInfo.  # noqa: E501
        :rtype: int
        """
        return self._min_length

    @min_length.setter
    def min_length(self, min_length):
        """Sets the min_length of this BTMetadataPropertyValidatorInfo.


        :param min_length: The min_length of this BTMetadataPropertyValidatorInfo.  # noqa: E501
        :type: int
        """

        self._min_length = min_length

    @property
    def max_length(self):
        """Gets the max_length of this BTMetadataPropertyValidatorInfo.  # noqa: E501


        :return: The max_length of this BTMetadataPropertyValidatorInfo.  # noqa: E501
        :rtype: int
        """
        return self._max_length

    @max_length.setter
    def max_length(self, max_length):
        """Sets the max_length of this BTMetadataPropertyValidatorInfo.


        :param max_length: The max_length of this BTMetadataPropertyValidatorInfo.  # noqa: E501
        :type: int
        """

        self._max_length = max_length

    @property
    def min_date(self):
        """Gets the min_date of this BTMetadataPropertyValidatorInfo.  # noqa: E501


        :return: The min_date of this BTMetadataPropertyValidatorInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._min_date

    @min_date.setter
    def min_date(self, min_date):
        """Sets the min_date of this BTMetadataPropertyValidatorInfo.


        :param min_date: The min_date of this BTMetadataPropertyValidatorInfo.  # noqa: E501
        :type: datetime
        """

        self._min_date = min_date

    @property
    def max_date(self):
        """Gets the max_date of this BTMetadataPropertyValidatorInfo.  # noqa: E501


        :return: The max_date of this BTMetadataPropertyValidatorInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._max_date

    @max_date.setter
    def max_date(self, max_date):
        """Sets the max_date of this BTMetadataPropertyValidatorInfo.


        :param max_date: The max_date of this BTMetadataPropertyValidatorInfo.  # noqa: E501
        :type: datetime
        """

        self._max_date = max_date

    @property
    def min_count(self):
        """Gets the min_count of this BTMetadataPropertyValidatorInfo.  # noqa: E501


        :return: The min_count of this BTMetadataPropertyValidatorInfo.  # noqa: E501
        :rtype: int
        """
        return self._min_count

    @min_count.setter
    def min_count(self, min_count):
        """Sets the min_count of this BTMetadataPropertyValidatorInfo.


        :param min_count: The min_count of this BTMetadataPropertyValidatorInfo.  # noqa: E501
        :type: int
        """

        self._min_count = min_count

    @property
    def max_count(self):
        """Gets the max_count of this BTMetadataPropertyValidatorInfo.  # noqa: E501


        :return: The max_count of this BTMetadataPropertyValidatorInfo.  # noqa: E501
        :rtype: int
        """
        return self._max_count

    @max_count.setter
    def max_count(self, max_count):
        """Sets the max_count of this BTMetadataPropertyValidatorInfo.


        :param max_count: The max_count of this BTMetadataPropertyValidatorInfo.  # noqa: E501
        :type: int
        """

        self._max_count = max_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTMetadataPropertyValidatorInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
